.. project-template documentation master file, created by
   sphinx-quickstart on Mon Jan 18 14:44:12 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##########################################
Welcome to imbalanced-learn documentation!
##########################################

Contents:
=========

.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   install
   support

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: API Documentation

   api

.. toctree::
   :maxdepth: 2
   :caption: Tutorial - Examples

   auto_examples/index

.. toctree::
   :maxdepth: 1
   :caption: Addtional information

   whats_new
   todo
   about

See the `README <https://github.com/vighneshbirodkar/project-template/blob/master/README.md>`_
for more information.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

